@@ -22,12 +22,12 @@ from devo.__version__ import __version__
 @click.option('--version', "-v", is_flag=True, default=False)
 def cli(version):
     """ Initialize click """
-    pkg_dir =  os.path.abspath(os.path.join(
-        os.path.dirname(__file__), "..", "..",
-    ))
-    click.echo("devo-sdk {!s} from {!s} (python {!s})".format(__version__,
-                                                              pkg_dir,
-                                                              sys.version[:3]))
+    if version:
+        pkg_dir = os.path.abspath(os.path.join(
+            os.path.dirname(__file__), "..", "..",
+        ))
+        click.echo("devo-sdk {!s} from {!s} (python {!s})"
+                   .format(__version__, pkg_dir, sys.version[:3]))
 
 
 # Commands
@@ -40,6 +40,8 @@ def cli(version):
 @click.option('--key', help='Devo user key cert file.')
 @click.option('--cert', help='Devo user cert file.')
 @click.option('--chain', help='Devo chain.crt file.')
+@click.option('--sec_level', help='Sec level for opensslsocket. Default: None',
+              default=None)
 @click.option('--multiline/--no-multiline', help='Flag for multiline (With '
                                                  'break-line in msg). '
                                                  'Default False', default=False)
@@ -113,13 +115,23 @@ def data(**kwargs):
 @click.option('--key', help='Devo user key cert file.')
 @click.option('--cert', help='Devo user cert file.')
 @click.option('--chain', help='Devo chain.crt file.')
+@click.option('--sec_level', help='Sec level for opensslsocket. Default: None',
+              default=None)
 @click.option('--type', help='Connection type: SSL or TCP', default="SSL")
 @click.option('--name', '-n', help='Name for Lookup.')
+@click.option('--action', '-ac', help='INC or FULL.', default="FULL")
 @click.option('--file', '-f', help='The file that you want to send to Devo,'
                                    ' which will be sent line by line.')
 @click.option('--lkey', '-lk', help='Name of the column that contains the '
                                     'Lookup key. It has to be the exact name '
                                     'that appears in the header.')
+@click.option('--dkey', '-dk', help='Name of the column that contains the '
+                                    'action/delete key with "add" or "delete".'
+                                    'It has to be the exact name '
+                                    'that appears in the header.')
+@click.option('--detect-types/--no-detect-types', '-dt/-ndt',
+              help='Detect types of fields. Default: False',
+              default=False)
 @click.option('--delimiter', '-d', help='CSV Delimiter char.', default=",")
 @click.option('--quotechar', '-qc', help='CSV Quote char.', default='"')
 @click.option('--debug/--no-debug', help='For testing purposes', default=False)
@@ -129,13 +141,20 @@ def lookup(**kwargs):
     con = Sender(config=config)
     lookup = Lookup(name=config['name'], historic_tag=None, con=con)
 
-    with open(config['file']) as file:
-        line = file.readline()
+    # with open(config['file']) as file:
+    #     line = file.readline()
 
-        lookup.send_csv(config['file'], delimiter=config['delimiter'],
-                         quotechar=config['quotechar'],
-                         headers=line.rstrip().split(config['delimiter']),
-                         key=config['lkey'])
+    lookup.send_csv(config['file'], delimiter=config['delimiter'],
+                    quotechar=config['quotechar'],
+                    has_header=True,
+                    # headers=line.rstrip().split(config['delimiter']),
+                    key=config['lkey'],
+                    action=config.get("action", "FULL"),
+                    delete_field=config.get("dkey", None),
+                    types=config.get(("lookup", "types"),
+                                     config.get("types", None)
+                                     ),
+                    detect_types=config.get("detect_types", False))
 
 
 def configure(args):
@@ -182,4 +201,4 @@ def print_error(error, show_help=False):
     if show_help:
         click.echo("")
         click.echo(click.get_current_context().get_help())
-    click.echo(click.style(error, fg='red'), err=True)
\ No newline at end of file
+    click.echo(click.style(error, fg='red'), err=True)
